import HazardBall from '@/assets/images/nav-bar/hazard-ball.svg?react';
import HomeIcon from '@/assets/images/nav-bar/home.svg?react';
import MyIcon from '@/assets/images/nav-bar/my.svg?react';
import RiskIcon from '@/assets/images/nav-bar/risk.svg?react';
import StatisticIcon from '@/assets/images/nav-bar/statistic.svg?react';

import clsx from 'clsx';
import { CSSProperties } from 'react';
import styles from './nav-bar.module.scss';

const activeColorVar = {
  '--st1': '#28E3FF',
  '--st2': '#286EFF',
} as CSSProperties;

const activeColorVarForMy = {
  '--st1': '#28DAFF',
  '--st2': '#28BBFF',
  '--st3': '#28B4FF',
  '--st4': '#2875FF',
  '--st5': '#28DAFF',
  '--st6': '#2887FF',
} as CSSProperties;

const inactiveColorVar = {
  '--st1': '#616161',
  '--st2': '#616161',
  '--st3': '#616161',
  '--st4': '#616161',
  '--st5': '#616161',
  '--st6': '#616161',
} as CSSProperties;

const getNavBarItem = (
  IconC: React.FC,
  text: string,
  isActive: boolean,
  activeStyle: CSSProperties = activeColorVar
) => (
  <div style={isActive ? activeStyle : inactiveColorVar}>
    <div className={styles.icon}>
      <IconC />
    </div>
    <div className={clsx(styles.text, isActive && styles.active)}>{text}</div>
  </div>
);

export default function NavBar() {
  return (
    <div className={styles.navBar}>
      <div className={styles.container}>
        {getNavBarItem(HomeIcon, '首页', true)}
        {getNavBarItem(StatisticIcon, '统计', false)}

        <div style={activeColorVar}>
          <div className={styles.icon}>
            <span className="relative -top-1/2">
              <div className={styles.half}>
                <HazardBall height={50} width={50} />
              </div>
            </span>
          </div>
          <div className={styles.text}>隐患列表</div>
        </div>
        {getNavBarItem(RiskIcon, '风险', false)}
        {getNavBarItem(MyIcon, '我的', false, activeColorVarForMy)}
      </div>
    </div>
  );
}
