import { BasicApi } from '@/apis/basic';
import { useMount, useRequest } from 'ahooks';
import { useCallback } from 'react';

function useBasic() {
  const { data: jobs = [], loading: jobsLoading, runAsync: getJobs } = useRequest(BasicApi.getJobList);
  const {
    data: departments = [],
    loading: departmentsLoading,
    runAsync: getDepartments,
  } = useRequest(BasicApi.getDepartmentList, {
    manual: true,
  });
  const {
    data: equipments = [],
    loading: equipmentsLoading,
    runAsync: getEquipments,
  } = useRequest(BasicApi.getEquipmentList, {
    manual: true,
  });
  const {
    data: operations = [],
    loading: operationsLoading,
    runAsync: getOperations,
  } = useRequest(BasicApi.getOperationList, {
    manual: true,
  });
  const {
    data: positions = [],
    loading: positionsLoading,
    runAsync: getPositions,
  } = useRequest(BasicApi.getPositionList, {
    manual: true,
  });
  const {
    data: units = [],
    loading: unitsLoading,
    runAsync: getUnits,
  } = useRequest(BasicApi.getUnitList, {
    manual: true,
  });

  const getJobName = useCallback(
    (jobId: number) => {
      return jobs.find(job => job.id === jobId)?.name || '';
    },
    [jobs]
  );

  const getDepartmentName = useCallback(
    (departmentId: number) => {
      return departments.find(department => department.id === departmentId)?.name || '';
    },
    [departments]
  );

  useMount(() => {
    getJobs();
    getDepartments();
    getEquipments();
    getOperations();
    getPositions();
    getUnits();
  });

  return {
    jobs,
    jobsLoading,
    getJobs,

    departments,
    departmentsLoading,
    getDepartments,

    equipments,
    equipmentsLoading,
    getEquipments,

    operations,
    operationsLoading,
    getOperations,

    positions,
    positionsLoading,
    getPositions,

    units,
    unitsLoading,
    getUnits,

    getJobName,
    getDepartmentName,
  };
}

export default useBasic;
