import HazardHandleIcon from '@/assets/icons/task/hazard-handle.svg?react';
import HazardInspectIcon from '@/assets/icons/task/hazard-inspect.svg?react';
import PlanCardIcon from '@/assets/images/portal/plan-card.png';
import RiskCardIcon from '@/assets/images/portal/risk-card.png';
import NavBar from '@/components/nav-bar';
import NoData from '@/components/no-data';
import UserInfo from '@/components/user-info';
import useBasic from '@/hooks/useBasic';
import { ArrowSize8 } from '@nutui/icons-react';
import { Button } from '@nutui/nutui-react';
import clsx from 'clsx';
import { useState } from 'react';
import './portal.scss';

export default function PortalPage() {
  useBasic();
  const [activeRiskLevel, setActiveRiskLevel] = useState('R1');
  return (
    <>
      <div className="portal-header-bg">
        <UserInfo />
        <div className="grid grid-cols-2 gap-3 px-3 mt-5">
          <div className="portal-card blue">
            <div className="title">我发起的</div>
            <div className="text">
              <span>今日</span>
              <span>3</span>
              <span>条提交记录</span>
            </div>
          </div>

          <div className={clsx('portal-card purple', 'point')}>
            <div className="title">我的审批</div>
            <div className="text">
              <span>3</span>
              <span>条审批待处理</span>
            </div>
          </div>
        </div>
      </div>
      <div className="portal-content-bg pb-8">
        <div className="p-3">
          <div className="portal-panel mb-4">
            <div className="header">我的工作台</div>
            <div className="content">
              <div className="grid grid-cols-2 gap-4">
                <div className="workbench-card blue">
                  <div>
                    <div className="title">风险/隐患提交</div>
                    <div className="vice">隐患副标题标题</div>
                  </div>
                  <div>
                    <img src={RiskCardIcon} alt="" />
                  </div>
                </div>
                <div className="workbench-card orange">
                  <div>
                    <div className="title">排查计划</div>
                    <div className="vice">排查计划副标题</div>
                  </div>
                  <div>
                    <img src={PlanCardIcon} alt="" />
                  </div>
                </div>
              </div>
            </div>
          </div>
          <div className="portal-panel mb-4">
            <div className="header">我的任务</div>
            <div className="content">
              <div className="task-item">
                <div>
                  <HazardInspectIcon height={78} width={78} />
                </div>
                <div className="flex-1 pb-4">
                  <div className="title">
                    <span>隐患排查：</span>
                    <span className="underline">3起</span>
                  </div>
                  <div className="deadline">
                    <span>临期任务：</span>
                    <span className="underline">1起</span>
                  </div>
                </div>
                <div className="pb-4">
                  <Button
                    style={{
                      margin: 8,
                      backgroundColor: '#EBF2FF',
                      borderColor: '#AFCBFF',
                      color: '#3480FE',
                    }}
                  >
                    去完成
                  </Button>
                </div>
              </div>
              <div className="task-item">
                <div>
                  <HazardHandleIcon height={78} width={78} />
                </div>
                <div className="flex-1 pb-4">
                  <div className="title">
                    <span>隐患治理：</span>
                    <span className="underline">7起</span>
                  </div>
                  <div className="deadline">
                    <span>临期任务：</span>
                    <span className="underline">2起</span>
                  </div>
                </div>
                <div className="pb-4">
                  <Button
                    style={{
                      margin: 8,
                      backgroundColor: '#EBF2FF',
                      borderColor: '#AFCBFF',
                      color: '#3480FE',
                    }}
                  >
                    去完成
                  </Button>
                </div>
              </div>
            </div>
          </div>
          <div className="portal-panel mb-4">
            <div className="header">
              <div>风险管控</div>
              <div>
                <Button
                  size="small"
                  color="#EBF2FF"
                  style={{
                    margin: 8,
                  }}
                >
                  <span style={{ color: '#3987F3', fontSize: 12 }}>查看全部</span>
                  <ArrowSize8 height={10} className="relative -top-[1px]" style={{ color: '#3987F3', fontSize: 12 }} />
                </Button>
              </div>
            </div>
            <div className="content" style={{ minHeight: 260 }}>
              <div className="py-3 text-nowrap overflow-y-hidden overflow-x-auto">
                {['R1', 'R2', 'R2*', 'R3', 'R4'].map(item => (
                  <button
                    key={item}
                    className={clsx('risk-level-button', item === activeRiskLevel && 'active')}
                    onClick={() => setActiveRiskLevel(item)}
                  >
                    {item}
                  </button>
                ))}
              </div>
              <div className="flex-center pt-8">
                <NoData height={93} width={128} text="当前暂无风险" />
              </div>
            </div>
          </div>
        </div>
        <NavBar />
      </div>
    </>
  );
}
