import { useUserStore } from '@/store/user';
import axios, { AxiosInstance } from 'axios';

// create an axios request
const request: AxiosInstance = axios.create({
  baseURL: '/api', // url = base url + request url
  withCredentials: true, // send cookies when cross-domain requests
  timeout: 10 * 1000, // request timeout，10秒
  // transformResponse: [
  //   (data) => {
  // Do whatever you want to transform the data
  //     return JSONbig.parse(data)
  //   }
  // ]
});

// request interceptor
request.interceptors.request.use(
  config => {
    if (config.url === undefined) {
      config.url = '';
    } // do something before request is sen
    const token = useUserStore.getState().token;
    if (token) {
      config.headers.Authorization = token;
    }
    return config;
  },
  error => {
    // do something with request error
    // console.log(error) // for debug
    return Promise.reject(error);
  }
);

// response interceptor
request.interceptors.response.use(
  /**
   * If you want to get http information such as headers or status
   * Please return  response => response
   */

  /**
   * Determine the request status by custom code
   * Here is just an example
   * You can also judge the status by HTTP Status Code
   */
  response => {
    const res = response.data;
    if (!res || res.code === -1) {
      return Promise.reject(res);
    }
    return res;
  },
  error => {
    if (error.response && error.response.data?.message) {
      return Promise.reject(new Error(error.response.data.message));
    }
    return Promise.reject(new Error(error.message));
  }
);

export default request;
